==> libreoffice_4.2.8.orig.tar.xz: libreoffice-4.2.8/oox/source/drawingml/chart/datasourceconverter.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "oox/drawingml/chart/datasourceconverter.hxx"

#include <com/sun/star/chart2/XChartDocument.hpp>
#include "oox/drawingml/chart/chartconverter.hxx"
#include "oox/drawingml/chart/datasourcemodel.hxx"
#include "oox/token/properties.hxx"

namespace oox {
namespace drawingml {
namespace chart {

// ============================================================================

using namespace ::com::sun::star::chart2::data;
using namespace ::com::sun::star::uno;

// ============================================================================

DataSequenceConverter::DataSequenceConverter( const ConverterRoot& rParent, DataSequenceModel& rModel ) :
    ConverterBase< DataSequenceModel >( rParent, rModel )
{
}

DataSequenceConverter::~DataSequenceConverter()
{
}

Reference< XDataSequence > DataSequenceConverter::createDataSequence( const OUString& rRole )
{
    // create data sequence from data source model (virtual call at chart converter)
    Reference< XDataSequence > xDataSeq;
    if( getChartConverter() )
    {
        // the internal data table does not support complex labels
        // this is only supported in Calc!!!
        // merge the labels into a single one
        if(rRole == "label")
        {
            mrModel.mnPointCount = std::min<sal_Int32>(mrModel.mnPointCount, 1);
            OUStringBuffer aTitle;
            bool bFirst = true;
            for(DataSequenceModel::AnyMap::const_iterator itr = mrModel.maData.begin(),
                    itrEnd = mrModel.maData.end(); itr != itrEnd; ++itr)
            {
                Any aAny = itr->second;
                if(aAny.has<OUString>())
                {
                    if(!bFirst)
                        aTitle.append(" ");

                    aTitle.append(aAny.get<OUString>());
                    bFirst = false;
                }
            }

            if(!bFirst)
            {
                mrModel.maData.clear();
                mrModel.maData.insert(std::make_pair<sal_Int32, Any>(1, Any(aTitle.makeStringAndClear())));
            }
        }
        xDataSeq = getChartConverter()->createDataSequence(getChartDocument()->getDataProvider(), mrModel, rRole);

        // set sequence role
        PropertySet aSeqProp( xDataSeq );
        aSeqProp.setProperty( PROP_Role, rRole );
    }
    return xDataSeq;
}

// ============================================================================

DataSourceConverter::DataSourceConverter( const ConverterRoot& rParent, DataSourceModel& rModel ) :
    ConverterBase< DataSourceModel >( rParent, rModel )
{
}

DataSourceConverter::~DataSourceConverter()
{
}

Reference< XDataSequence > DataSourceConverter::createDataSequence( const OUString& rRole )
{
    Reference< XDataSequence > xDataSeq;
    if( mrModel.mxDataSeq.is() )
    {
        DataSequenceConverter aDataSeqConv( *this, *mrModel.mxDataSeq );
        xDataSeq = aDataSeqConv.createDataSequence( rRole );
    }
    return xDataSeq;
}

// ============================================================================

} // namespace chart
} // namespace drawingml
} // namespace oox

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-4.3.0.4.tar.xz: libreoffice-4.3.0.4/oox/source/drawingml/chart/datasourceconverter.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "oox/drawingml/chart/datasourceconverter.hxx"

#include <com/sun/star/chart2/XChartDocument.hpp>
#include "oox/drawingml/chart/chartconverter.hxx"
#include "oox/drawingml/chart/datasourcemodel.hxx"
#include "oox/token/properties.hxx"

namespace oox {
namespace drawingml {
namespace chart {



using namespace ::com::sun::star::chart2::data;
using namespace ::com::sun::star::uno;



DataSequenceConverter::DataSequenceConverter( const ConverterRoot& rParent, DataSequenceModel& rModel ) :
    ConverterBase< DataSequenceModel >( rParent, rModel )
{
}

DataSequenceConverter::~DataSequenceConverter()
{
}

Reference< XDataSequence > DataSequenceConverter::createDataSequence( const OUString& rRole )
{
    // create data sequence from data source model (virtual call at chart converter)
    Reference< XDataSequence > xDataSeq;
    if( getChartConverter() )
    {
        // the internal data table does not support complex labels
        // this is only supported in Calc!!!
        // merge the labels into a single one
        if(rRole == "label")
        {
            mrModel.mnPointCount = std::min<sal_Int32>(mrModel.mnPointCount, 1);
            OUStringBuffer aTitle;
            bool bFirst = true;
            for(DataSequenceModel::AnyMap::const_iterator itr = mrModel.maData.begin(),
                    itrEnd = mrModel.maData.end(); itr != itrEnd; ++itr)
            {
                Any aAny = itr->second;
                if(aAny.has<OUString>())
                {
                    if(!bFirst)
                        aTitle.append(" ");

                    aTitle.append(aAny.get<OUString>());
                    bFirst = false;
                }
            }

            if(!bFirst)
            {
                mrModel.maData.clear();
                mrModel.maData.insert(std::make_pair<sal_Int32, Any>(1, Any(aTitle.makeStringAndClear())));
            }
        }
        xDataSeq = getChartConverter()->createDataSequence( getChartDocument()->getDataProvider(), mrModel );

        // set sequen   ce role
        PropertySet aSeqProp( xDataSeq );
        aSeqProp.setProperty( PROP_Role, rRole );
    }
    return xDataSeq;
}



DataSourceConverter::DataSourceConverter( const ConverterRoot& rParent, DataSourceModel& rModel ) :
    ConverterBase< DataSourceModel >( rParent, rModel )
{
}

DataSourceConverter::~DataSourceConverter()
{
}

Reference< XDataSequence > DataSourceConverter::createDataSequence( const OUString& rRole )
{
    Reference< XDataSequence > xDataSeq;
    if( mrModel.mxDataSeq.is() )
    {
        DataSequenceConverter aDataSeqConv( *this, *mrModel.mxDataSeq );
        xDataSeq = aDataSeqConv.createDataSequence( rRole );
    }
    return xDataSeq;
}



} // namespace chart
} // namespace drawingml
} // namespace oox

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
